Struct btc_tools::cli::BrainWalletArgs
source · pub struct BrainWalletArgs {
pub iter_num: usize,
pub type: AddressTypeArg,
pub compressed: bool,
pub pass_file: Option<PathBuf>,
}Expand description
Brain-wallet derivation
For detailed algorithm and implementation, please refer to the source code :).
Fields
iter_num: usizeIteration number
This is to make a deliberately-slow hash function
type: AddressTypeArgcompressed: boolpass_file: Option<PathBuf>Read passphrase from file
This reads the first line of the given file.