Struct btc_tools::cli::ValidateAddressArgs
source · pub struct ValidateAddressArgs {
pub bip38: bool,
pub jobs: Option<usize>,
pub decode: bool,
}Expand description
Validate the correctness of: private key -> address, to avoid scams
This reads from stdin. Line format: <WIF/BIP-38>
If the address is not the expected one derived from the private key, or any error occurs, this program aborts with the reason; otherwise, all is okay.
Fields
bip38: boolDecrypt BIP-38
jobs: Option<usize>The amount of parallel workers; defaults to the CPU number
decode: boolDecode BIP38. NOTE: this will print secret keys (in WIF) out